@@ -3,6 +3,7 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
+import enum
 from dataclasses import dataclass, field
 from pathlib import Path
 from typing import List, Optional, Set
@@ -12,6 +13,11 @@ TEXT: str = "text"
 JSON: str = "json"
 
 
+class MissingFlowsKind(str, enum.Enum):
+    OBSCURE: str = "obscure"
+    TYPE: str = "type"
+
+
 @dataclass(frozen=True)
 class CommandArguments:
     local_configuration: Optional[str] = None
@@ -109,6 +115,7 @@ class InferArguments:
     log_identifier: Optional[str] = None
     logging_sections: Optional[str] = None
     no_future_annotations: bool = False
+    in_place: bool = False
     paths_to_modify: Optional[Set[Path]] = None
     print_only: bool = False
     read_stdin: bool = False
@@ -127,3 +134,25 @@ class StatisticsArguments:
     log_identifier: Optional[str] = None
     log_results: bool = False
     print_aggregates: bool = False
+
+
+@dataclass(frozen=True)
+class AnalyzeArguments:
+    debug: bool = False
+    dump_call_graph: Optional[str] = None
+    dump_model_query_results: Optional[str] = None
+    enable_memory_profiling: bool = False
+    enable_profiling: bool = False
+    find_missing_flows: Optional[MissingFlowsKind] = None
+    inline_decorators: bool = False
+    log_identifier: Optional[str] = None
+    maximum_tito_depth: Optional[int] = None
+    maximum_trace_length: Optional[int] = None
+    no_verify: bool = False
+    output: str = TEXT
+    repository_root: Optional[str] = None
+    rule: List[int] = field(default_factory=list)
+    save_results_to: Optional[str] = None
+    sequential: bool = False
+    taint_models_path: List[str] = field(default_factory=list)
+    use_cache: bool = False
