@@ -54,7 +54,9 @@ class Check(Reporting):
 
         search_path = [
             search_path.command_line_argument()
-            for search_path in self._configuration.get_existent_search_paths()
+            for search_path in (
+                self._configuration.expand_and_get_existent_search_paths()
+            )
         ]
 
         ignore_all_errors_paths = (
