@@ -6,6 +6,7 @@
 
 import json
 import logging
+import re
 import time
 from pathlib import Path
 from typing import Any, Dict, List, Mapping, Optional, Set, Type, Union
@@ -14,7 +15,7 @@ import libcst as cst
 from libcst._exceptions import ParserSyntaxError
 from libcst.metadata import MetadataWrapper
 
-from .. import command_arguments, log, statistics
+from .. import command_arguments, log, statistics_logger
 from ..analysis_directory import AnalysisDirectory
 from ..configuration import Configuration
 from ..statistics_collectors import (
@@ -42,6 +43,8 @@ def parse_path_to_module(path: Path) -> Optional[cst.Module]:
         return cst.parse_module(path.read_text())
     except (ParserSyntaxError, FileNotFoundError):
         return None
+    except UnicodeDecodeError as error:
+        raise RuntimeError(f"error decoding file at path {path}") from error
 
 
 def parse_path_to_metadata_module(path: Path) -> Optional[MetadataWrapper]:
@@ -160,8 +163,8 @@ class Statistics(Command):
     def _log_to_scuba(self, run_id: str, data: Dict[str, Any]) -> None:
         if self._configuration and self._configuration.logger:
             for path, counts in data["annotations"].items():
-                statistics.log_with_configuration(
-                    statistics.LoggerCategory.ANNOTATION_COUNTS,
+                statistics_logger.log_with_configuration(
+                    statistics_logger.LoggerCategory.ANNOTATION_COUNTS,
                     configuration=self._configuration,
                     integers=counts,
                     normals={"run_id": run_id, "path": path},
@@ -171,8 +174,8 @@ class Statistics(Command):
             for path, counts in data["ignores"].items():
                 self._log_fixmes(run_id, "ignore", counts, path)
             for path, counts in data["strict"].items():
-                statistics.log_with_configuration(
-                    statistics.LoggerCategory.STRICT_ADOPTION,
+                statistics_logger.log_with_configuration(
+                    statistics_logger.LoggerCategory.STRICT_ADOPTION,
                     configuration=self._configuration,
                     integers=counts,
                     normals={"run_id": run_id, "path": path},
@@ -182,8 +185,8 @@ class Statistics(Command):
         self, run_id: str, fixme_type: str, data: Dict[str, int], path: str
     ) -> None:
         for error_code, count in data.items():
-            statistics.log_with_configuration(
-                statistics.LoggerCategory.FIXME_COUNTS,
+            statistics_logger.log_with_configuration(
+                statistics_logger.LoggerCategory.FIXME_COUNTS,
                 configuration=self._configuration,
                 integers={"count": count},
                 normals={
@@ -195,7 +198,20 @@ class Statistics(Command):
             )
 
     def _find_paths(self) -> List[Path]:
-        return _find_paths(self._configuration.local_root, self._filter_paths)
+        paths = _find_paths(self._configuration.local_root, self._filter_paths)
+        return self._filter_excluded_paths(paths)
+
+    def _filter_excluded_paths(self, paths: List[Path]) -> List[Path]:
+        # Remove files completely excluded from the type checking
+        excludes = self.configuration.excludes
+        return list(
+            filter(
+                lambda path: not any(
+                    [re.match(exclude_pattern, path) for exclude_pattern in excludes]
+                ),
+                paths,
+            )
+        )
 
     def _aggregate_data(self, data: Dict[str, Any]) -> Dict[str, Any]:
         aggregate_annotations = {
