@@ -23,7 +23,7 @@ from ... import (
     command_arguments,
     commands,
     configuration as configuration_module,
-    statistics,
+    statistics_logger,
 )
 from . import (
     backend_arguments,
@@ -60,8 +60,8 @@ def _log_lsp_event(
         logger = remote_logging.logger
         if logger is not None:
             log_identifier = remote_logging.identifier
-            statistics.log(
-                category=statistics.LoggerCategory.LSP_EVENTS,
+            statistics_logger.log(
+                category=statistics_logger.LoggerCategory.LSP_EVENTS,
                 logger=logger,
                 integers=integers,
                 normals={
@@ -425,6 +425,7 @@ class StartSuccess:
 
 @dataclasses.dataclass(frozen=True)
 class StartFailure:
+    message: str
     detail: str
 
 
@@ -445,7 +446,7 @@ async def _start_pyre_server(
             }
 
             with start.background_server_log_file(
-                Path(pyre_arguments.log_path)
+                Path(pyre_arguments.base_arguments.log_path)
             ) as server_stderr:
                 server_process = await asyncio.create_subprocess_exec(
                     binary_location,
@@ -469,10 +470,19 @@ async def _start_pyre_server(
             )
 
         return StartSuccess()
-    except Exception:
+    except server_event.ServerStartException as error:
+        # We know where the exception come from. Let's keep the error details
+        # succinct.
+        message = str(error)
+        LOG.error(message)
+        return StartFailure(message=message, detail=message)
+    except Exception as error:
+        # These exceptions are unexpected. Let's keep verbose stack traces to
+        # help with post-mortem analyses.
+        message = str(error)
         detail = traceback.format_exc()
-        LOG.error(f"Exception occured during server start. {detail}")
-        return StartFailure(detail)
+        LOG.error(f"{detail}")
+        return StartFailure(message=message, detail=detail)
 
 
 @dataclasses.dataclass(frozen=True)
@@ -747,11 +757,13 @@ class PyreServerHandler(connection.BackgroundTask):
     def _auxiliary_logging_info(
         server_start_options: PyreServerStartOptions,
     ) -> Dict[str, Optional[str]]:
-        relative_local_root = server_start_options.start_arguments.relative_local_root
+        relative_local_root = (
+            server_start_options.start_arguments.base_arguments.relative_local_root
+        )
         return {
             "binary": server_start_options.binary,
-            "log_path": server_start_options.start_arguments.log_path,
-            "global_root": server_start_options.start_arguments.global_root,
+            "log_path": server_start_options.start_arguments.base_arguments.log_path,
+            "global_root": server_start_options.start_arguments.base_arguments.global_root,
             **(
                 {}
                 if relative_local_root is None
@@ -763,7 +775,7 @@ class PyreServerHandler(connection.BackgroundTask):
         server_identifier = server_start_options.server_identifier
         start_arguments = server_start_options.start_arguments
         socket_path = server_connection.get_default_socket_path(
-            log_directory=Path(start_arguments.log_path)
+            log_directory=Path(start_arguments.base_arguments.log_path)
         )
         try:
             async with connection.connect_in_text_mode(socket_path) as (
@@ -833,9 +845,8 @@ class PyreServerHandler(connection.BackgroundTask):
                         },
                     )
                     await self.show_status_message_to_client(
-                        f"Cannot start a new Pyre server at `{server_identifier}`."
-                        "To get more detailed error message, run `pyre` from "
-                        f"`{server_identifier} on the command line",
+                        f"Cannot start a new Pyre server at `{server_identifier}`. "
+                        f"{start_status.message}",
                         short_message="Pyre Stopped",
                         level=lsp.MessageType.WARNING,
                     )
