@@ -7,7 +7,7 @@ import dataclasses
 import logging
 import os
 from pathlib import Path
-from typing import List
+from typing import List, Dict
 
 from ... import commands, configuration as configuration_module, error as error_module
 from . import query, server_connection, remote_logging
@@ -27,22 +27,9 @@ def _relativize_error_path(
 
 
 def parse_validation_errors(
-    payload: object,
+    payload: Dict[str, object],
 ) -> List[error_module.ModelVerificationError]:
-    if not isinstance(payload, dict) or "response" not in payload:
-        message = f"Invalid payload for model validation: `{payload}`."
-        raise query.InvalidQueryResponse(message)
-
-    response_payload = payload["response"]
-    if not isinstance(response_payload, dict):
-        message = (
-            f"Invalid response payload for model validation: `{response_payload}`."
-        )
-        raise query.InvalidQueryResponse(message)
-
-    errors_payload = (
-        [] if "errors" not in response_payload else response_payload["errors"]
-    )
+    errors_payload = [] if "errors" not in payload else payload["errors"]
     if not isinstance(errors_payload, list):
         message = f"Invalid error payload for model validation: `{errors_payload}`."
         raise query.InvalidQueryResponse(message)
@@ -56,6 +43,23 @@ def parse_validation_errors(
     )
 
 
+def parse_validation_errors_response(
+    payload: object,
+) -> List[error_module.ModelVerificationError]:
+    if not isinstance(payload, dict) or "response" not in payload:
+        message = f"Invalid payload for model validation: `{payload}`."
+        raise query.InvalidQueryResponse(message)
+
+    response_payload = payload["response"]
+    if not isinstance(response_payload, dict):
+        message = (
+            f"Invalid response payload for model validation: `{response_payload}`."
+        )
+        raise query.InvalidQueryResponse(message)
+
+    return parse_validation_errors(response_payload)
+
+
 @remote_logging.log_usage(command_name="validate-models")
 def run(
     configuration: configuration_module.Configuration, output: str
@@ -65,7 +69,7 @@ def run(
     )
     try:
         response = query.query_server(socket_path, "validate_taint_models()")
-        validation_errors = parse_validation_errors(response.payload)
+        validation_errors = parse_validation_errors_response(response.payload)
         error_module.print_errors(
             validation_errors, output=output, error_kind="model verification"
         )
