@@ -119,6 +119,10 @@ class SearchPathElement(abc.ABC):
     def expand_relative_root(self, relative_root: str) -> "SearchPathElement":
         raise NotImplementedError
 
+    @abc.abstractmethod
+    def expand_glob(self) -> List["SearchPathElement"]:
+        raise NotImplementedError
+
 
 @dataclasses.dataclass(frozen=True)
 class SimpleSearchPathElement(SearchPathElement):
@@ -143,6 +147,14 @@ class SimpleSearchPathElement(SearchPathElement):
             _expand_relative_root(self.root, relative_root=relative_root)
         )
 
+    def expand_glob(self) -> List[SearchPathElement]:
+        expanded = sorted(glob.glob(self.get_root()))
+        if expanded:
+            return [SimpleSearchPathElement(path) for path in expanded]
+        else:
+            LOG.warning(f"'{self.path()}' does not match any paths.")
+            return []
+
 
 @dataclasses.dataclass(frozen=True)
 class SubdirectorySearchPathElement(SearchPathElement):
@@ -170,6 +182,9 @@ class SubdirectorySearchPathElement(SearchPathElement):
             subdirectory=self.subdirectory,
         )
 
+    def expand_glob(self) -> List["SearchPathElement"]:
+        return [self]
+
 
 @dataclasses.dataclass(frozen=True)
 class SitePackageSearchPathElement(SearchPathElement):
@@ -193,6 +208,9 @@ class SitePackageSearchPathElement(SearchPathElement):
         # Site package does not participate in root expansion.
         return self
 
+    def expand_glob(self) -> List["SearchPathElement"]:
+        return [self]
+
 
 @dataclasses.dataclass
 class ExtensionElement:
@@ -288,9 +306,16 @@ def _in_virtual_environment(override: Optional[bool] = None) -> bool:
     return sys.prefix != sys.base_prefix
 
 
-def _get_existent_paths(paths: Sequence[SearchPathElement]) -> List[SearchPathElement]:
+def _expand_and_get_existent_paths(
+    paths: Sequence[SearchPathElement],
+) -> List[SearchPathElement]:
+    expanded_search_paths = [
+        expanded_path
+        for search_path_element in paths
+        for expanded_path in search_path_element.expand_glob()
+    ]
     existent_paths = []
-    for search_path_element in paths:
+    for search_path_element in expanded_search_paths:
         search_path = search_path_element.path()
         if os.path.exists(search_path):
             existent_paths.append(search_path_element)
@@ -328,6 +353,31 @@ class PythonVersion:
         return f"{self.major}.{self.minor}.{self.micro}"
 
 
+@dataclass(frozen=True)
+class SharedMemory:
+    heap_size: Optional[int] = None
+    dependency_table_power: Optional[int] = None
+    hash_table_power: Optional[int] = None
+
+    def to_json(self) -> Dict[str, int]:
+        heap_size = self.heap_size
+        dependency_table_power = self.dependency_table_power
+        hash_table_power = self.hash_table_power
+        return {
+            **({"heap_size": heap_size} if heap_size is not None else {}),
+            **(
+                {"dependency_table_power": dependency_table_power}
+                if dependency_table_power is not None
+                else {}
+            ),
+            **(
+                {"hash_table_power": hash_table_power}
+                if hash_table_power is not None
+                else {}
+            ),
+        }
+
+
 @dataclass(frozen=True)
 class PartialConfiguration:
     autocomplete: Optional[bool] = None
@@ -340,7 +390,6 @@ class PartialConfiguration:
     excludes: Sequence[str] = field(default_factory=list)
     extensions: Sequence[ExtensionElement] = field(default_factory=list)
     file_hash: Optional[str] = None
-    formatter: Optional[str] = None
     ignore_all_errors: Sequence[str] = field(default_factory=list)
     ignore_infer: Sequence[str] = field(default_factory=list)
     isolation_prefix: Optional[str] = None
@@ -349,6 +398,7 @@ class PartialConfiguration:
     oncall: Optional[str] = None
     other_critical_files: Sequence[str] = field(default_factory=list)
     python_version: Optional[PythonVersion] = None
+    shared_memory: SharedMemory = SharedMemory()
     search_path: Sequence[SearchPathElement] = field(default_factory=list)
     source_directories: Optional[Sequence[SearchPathElement]] = None
     strict: Optional[bool] = None
@@ -367,9 +417,7 @@ class PartialConfiguration:
     @staticmethod
     def _get_extra_keys() -> Set[str]:
         return {
-            "accept_command_v2",
             "create_open_source_configuration",
-            "differential",
             "saved_state",
             "stable_client",
             "taint_models_path",
@@ -399,7 +447,6 @@ class PartialConfiguration:
             excludes=arguments.exclude,
             extensions=[],
             file_hash=None,
-            formatter=arguments.formatter,
             ignore_all_errors=[],
             ignore_infer=[],
             isolation_prefix=arguments.isolation_prefix,
@@ -412,6 +459,11 @@ class PartialConfiguration:
                 if python_version_string is not None
                 else None
             ),
+            shared_memory=SharedMemory(
+                heap_size=arguments.shared_memory_heap_size,
+                dependency_table_power=arguments.shared_memory_dependency_table_power,
+                hash_table_power=arguments.shared_memory_hash_table_power,
+            ),
             search_path=[
                 SimpleSearchPathElement(element) for element in arguments.search_path
             ],
@@ -517,6 +569,24 @@ class PartialConfiguration:
                     + f"'{python_version_json}'"
                 )
 
+            shared_memory_json = ensure_option_type(
+                configuration_json, "shared_memory", dict
+            )
+            if shared_memory_json is None:
+                shared_memory = SharedMemory()
+            else:
+                shared_memory = SharedMemory(
+                    heap_size=ensure_option_type(shared_memory_json, "heap_size", int),
+                    dependency_table_power=ensure_option_type(
+                        shared_memory_json, "dependency_table_power", int
+                    ),
+                    hash_table_power=ensure_option_type(
+                        shared_memory_json, "hash_table_power", int
+                    ),
+                )
+                for unrecognized_key in shared_memory_json:
+                    LOG.warning(f"Unrecognized configuration item: {unrecognized_key}")
+
             source_directories_json = ensure_option_type(
                 configuration_json, "source_directories", list
             )
@@ -555,7 +625,6 @@ class PartialConfiguration:
                     for json in ensure_list(configuration_json, "extensions")
                 ],
                 file_hash=file_hash,
-                formatter=ensure_option_type(configuration_json, "formatter", str),
                 ignore_all_errors=ensure_string_list(
                     configuration_json, "ignore_all_errors"
                 ),
@@ -572,6 +641,7 @@ class PartialConfiguration:
                     configuration_json, "critical_files"
                 ),
                 python_version=python_version,
+                shared_memory=shared_memory,
                 search_path=search_path,
                 source_directories=source_directories,
                 strict=ensure_option_type(configuration_json, "strict", bool),
@@ -627,9 +697,6 @@ class PartialConfiguration:
         buck_builder_binary = self.buck_builder_binary
         if buck_builder_binary is not None:
             buck_builder_binary = expand_relative_path(root, buck_builder_binary)
-        formatter = self.formatter
-        if formatter is not None:
-            formatter = expand_relative_path(root, formatter)
         logger = self.logger
         if logger is not None:
             logger = expand_relative_path(root, logger)
@@ -655,7 +722,6 @@ class PartialConfiguration:
             excludes=self.excludes,
             extensions=self.extensions,
             file_hash=self.file_hash,
-            formatter=formatter,
             ignore_all_errors=[
                 expand_relative_path(root, path) for path in self.ignore_all_errors
             ],
@@ -670,6 +736,7 @@ class PartialConfiguration:
                 expand_relative_path(root, path) for path in self.other_critical_files
             ],
             python_version=self.python_version,
+            shared_memory=self.shared_memory,
             search_path=[path.expand_relative_root(root) for path in self.search_path],
             source_directories=source_directories,
             strict=self.strict,
@@ -723,7 +790,6 @@ def merge_partial_configurations(
         excludes=prepend_base(base.excludes, override.excludes),
         extensions=prepend_base(base.extensions, override.extensions),
         file_hash=overwrite_base(base.file_hash, override.file_hash),
-        formatter=overwrite_base(base.formatter, override.formatter),
         ignore_all_errors=prepend_base(
             base.ignore_all_errors, override.ignore_all_errors
         ),
@@ -740,6 +806,19 @@ def merge_partial_configurations(
             base.other_critical_files, override.other_critical_files
         ),
         python_version=overwrite_base(base.python_version, override.python_version),
+        shared_memory=SharedMemory(
+            heap_size=overwrite_base(
+                base.shared_memory.heap_size, override.shared_memory.heap_size
+            ),
+            dependency_table_power=overwrite_base(
+                base.shared_memory.dependency_table_power,
+                override.shared_memory.dependency_table_power,
+            ),
+            hash_table_power=overwrite_base(
+                base.shared_memory.hash_table_power,
+                override.shared_memory.hash_table_power,
+            ),
+        ),
         search_path=prepend_base(base.search_path, override.search_path),
         source_directories=raise_when_overridden(
             base.source_directories,
@@ -777,7 +856,6 @@ class Configuration:
     excludes: Sequence[str] = field(default_factory=list)
     extensions: Sequence[ExtensionElement] = field(default_factory=list)
     file_hash: Optional[str] = None
-    formatter: Optional[str] = None
     ignore_all_errors: Sequence[str] = field(default_factory=list)
     ignore_infer: Sequence[str] = field(default_factory=list)
     isolation_prefix: Optional[str] = None
@@ -786,6 +864,7 @@ class Configuration:
     oncall: Optional[str] = None
     other_critical_files: Sequence[str] = field(default_factory=list)
     python_version: Optional[PythonVersion] = None
+    shared_memory: SharedMemory = SharedMemory()
     relative_local_root: Optional[str] = None
     search_path: Sequence[SearchPathElement] = field(default_factory=list)
     source_directories: Optional[Sequence[SearchPathElement]] = None
@@ -826,7 +905,6 @@ class Configuration:
             excludes=partial_configuration.excludes,
             extensions=partial_configuration.extensions,
             file_hash=partial_configuration.file_hash,
-            formatter=partial_configuration.formatter,
             ignore_all_errors=partial_configuration.ignore_all_errors,
             ignore_infer=partial_configuration.ignore_infer,
             isolation_prefix=partial_configuration.isolation_prefix,
@@ -835,6 +913,7 @@ class Configuration:
             oncall=partial_configuration.oncall,
             other_critical_files=partial_configuration.other_critical_files,
             python_version=partial_configuration.python_version,
+            shared_memory=partial_configuration.shared_memory,
             relative_local_root=relative_local_root,
             search_path=[
                 path.expand_global_root(str(project_root)) for path in search_path
@@ -851,7 +930,7 @@ class Configuration:
                 partial_configuration.use_buck_source_database, default=False
             ),
             use_command_v2=_get_optional_value(
-                partial_configuration.use_command_v2, default=False
+                partial_configuration.use_command_v2, default=True
             ),
             version_hash=partial_configuration.version_hash,
         )
@@ -876,7 +955,6 @@ class Configuration:
         binary = self.binary
         buck_builder_binary = self.buck_builder_binary
         buck_mode = self.buck_mode
-        formatter = self.formatter
         isolation_prefix = self.isolation_prefix
         logger = self.logger
         number_of_workers = self.number_of_workers
@@ -902,7 +980,6 @@ class Configuration:
             "do_not_ignore_all_errors_in": list(self.do_not_ignore_all_errors_in),
             "excludes": list(self.excludes),
             "extensions": list(self.extensions),
-            **({"formatter": formatter} if formatter is not None else {}),
             "ignore_all_errors": list(self.ignore_all_errors),
             "ignore_infer": list(self.ignore_infer),
             **(
@@ -919,6 +996,11 @@ class Configuration:
                 if python_version is not None
                 else {}
             ),
+            **(
+                {"shared_memory": self.shared_memory.to_json()}
+                if self.shared_memory != SharedMemory()
+                else {}
+            ),
             **(
                 {"relative_local_root": relative_local_root}
                 if relative_local_root is not None
@@ -943,10 +1025,10 @@ class Configuration:
     def get_source_directories(self) -> List[SearchPathElement]:
         return list(self.source_directories or [])
 
-    # Validation of search paths cannot happen at Configuration creation
+    # Expansion and validation of search paths cannot happen at Configuration creation
     # because link trees need to be built first.
-    def get_existent_search_paths(self) -> List[SearchPathElement]:
-        existent_paths = _get_existent_paths(self.search_path)
+    def expand_and_get_existent_search_paths(self) -> List[SearchPathElement]:
+        existent_paths = _expand_and_get_existent_paths(self.search_path)
 
         typeshed_root = self.get_typeshed_respecting_override()
         typeshed_paths = (
@@ -965,7 +1047,7 @@ class Configuration:
         # List[SimpleSearchPathElement]]`
         return existent_paths + typeshed_paths
 
-    def filter_nonexistent_paths(self) -> "Configuration":
+    def expand_and_filter_nonexistent_paths(self) -> "Configuration":
         source_directories = self.source_directories
 
         return Configuration(
@@ -980,7 +1062,6 @@ class Configuration:
             excludes=self.excludes,
             extensions=self.extensions,
             file_hash=self.file_hash,
-            formatter=self.formatter,
             ignore_all_errors=self.ignore_all_errors,
             ignore_infer=self.ignore_infer,
             isolation_prefix=self.isolation_prefix,
@@ -989,9 +1070,10 @@ class Configuration:
             oncall=self.oncall,
             other_critical_files=self.other_critical_files,
             python_version=self.python_version,
+            shared_memory=self.shared_memory,
             relative_local_root=self.relative_local_root,
             search_path=self.search_path,
-            source_directories=_get_existent_paths(source_directories)
+            source_directories=_expand_and_get_existent_paths(source_directories)
             if source_directories
             else None,
             strict=self.strict,
@@ -1160,19 +1242,19 @@ def create_configuration(
         if found_root is None:
             raise InvalidConfiguration(
                 "A local configuration path was explicitly specified, but no"
-                + f"{CONFIGURATION_FILE} file was found in {search_base}"
+                + f" {CONFIGURATION_FILE} file was found in {search_base}"
                 + " or its parents."
             )
         elif found_root.local_root is None:
             raise InvalidConfiguration(
                 "A local configuration path was explicitly specified, but no"
-                + f"{LOCAL_CONFIGURATION_FILE} file was found in {search_base}"
+                + f" {LOCAL_CONFIGURATION_FILE} file was found in {search_base}"
                 + " or its parents."
             )
 
     command_argument_configuration = PartialConfiguration.from_command_arguments(
         arguments
-    )
+    ).expand_relative_paths(str(Path.cwd()))
     if found_root is None:
         project_root = Path.cwd()
         relative_local_root = None
@@ -1193,13 +1275,14 @@ def create_configuration(
                 ).expand_relative_paths(str(local_root)),
             )
         partial_configuration = merge_partial_configurations(
-            base=partial_configuration, override=command_argument_configuration
+            base=partial_configuration,
+            override=command_argument_configuration,
         )
 
     configuration = Configuration.from_partial_configuration(
         project_root, relative_local_root, partial_configuration
     )
-    return configuration.filter_nonexistent_paths()
+    return configuration.expand_and_filter_nonexistent_paths()
 
 
 def check_nested_local_configuration(configuration: Configuration) -> None:
