@@ -14,6 +14,7 @@ CONFIGURATION_FILE: str = ".pyre_configuration"
 LOCAL_CONFIGURATION_FILE: str = ".pyre_configuration.local"
 BINARY_NAME: str = "pyre.bin"
 CLIENT_NAME: str = "pyre-client"
+LOG_DIRECTORY: str = ".pyre"
 
 
 LOG: logging.Logger = logging.getLogger(__name__)
@@ -143,21 +144,15 @@ def find_typeshed_search_paths(typeshed_root: Path) -> List[Path]:
     as search paths for Pyre.
     """
     search_path = []
-    typeshed_subdirectories = ["stdlib", "third_party"]
-    for typeshed_subdirectory_name in typeshed_subdirectories:
-        typeshed_subdirectory = typeshed_root / typeshed_subdirectory_name
-        if not typeshed_subdirectory.is_dir():
-            continue
-
-        # Always prefer newer version over older version
-        version_names = sorted(
-            (x.name for x in typeshed_subdirectory.iterdir()), reverse=True
-        )
-        for version_name in version_names:
-            # Anything under 2/ or 2.x is unusable for Pyre
-            if version_name.startswith("2") and version_name != "2and3":
-                continue
-            search_path.append(typeshed_subdirectory / version_name)
+    third_party_root = typeshed_root / "stubs"
+    third_party_subdirectories = (
+        sorted(third_party_root.iterdir()) if third_party_root.is_dir() else []
+    )
+    for typeshed_subdirectory in itertools.chain(
+        [typeshed_root / "stdlib"], third_party_subdirectories
+    ):
+        if typeshed_subdirectory.is_dir():
+            search_path.append(typeshed_subdirectory)
     return search_path
 
 
