@@ -3,8 +3,6 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
-from __future__ import annotations
-
 import json
 import logging
 import os
@@ -14,7 +12,7 @@ import time
 import traceback
 from dataclasses import replace
 from pathlib import Path
-from typing import Iterable, List
+from typing import Iterable, List, Optional
 
 import click
 
@@ -26,10 +24,9 @@ from . import (
     filesystem,
     log,
     recently_used_configurations,
-    statistics as statistics_module,
+    statistics_logger,
 )
 from .commands import Command, ExitCode, v2
-from .commands.analyze import MissingFlowsKind
 from .exceptions import EnvironmentException
 from .version import __version__
 
@@ -41,13 +38,13 @@ def _log_statistics(
     command: Command,
     start_time: float,
     client_exception_message: str,
-    error_message: str | None,
+    error_message: Optional[str],
     exit_code: int,
 ) -> None:
     configuration = command.configuration
     if configuration is not None:
-        statistics_module.log_with_configuration(
-            category=statistics_module.LoggerCategory.USAGE,
+        statistics_logger.log_with_configuration(
+            category=statistics_logger.LoggerCategory.USAGE,
             configuration=configuration,
             integers={
                 "exit_code": exit_code,
@@ -64,13 +61,17 @@ def _log_statistics(
         )
 
 
-def _show_pyre_version_as_text(binary_version: str | None, client_version: str) -> None:
+def _show_pyre_version_as_text(
+    binary_version: Optional[str], client_version: str
+) -> None:
     if binary_version:
         log.stdout.write(f"Binary version: {binary_version}\n")
     log.stdout.write(f"Client version: {__version__}\n")
 
 
-def _show_pyre_version_as_json(binary_version: str | None, client_version: str) -> None:
+def _show_pyre_version_as_json(
+    binary_version: Optional[str], client_version: str
+) -> None:
     version_json = {
         **({} if binary_version is None else {"binary": binary_version}),
         "client": client_version,
@@ -79,7 +80,7 @@ def _show_pyre_version_as_json(binary_version: str | None, client_version: str)
 
 
 def _show_pyre_version(arguments: command_arguments.CommandArguments) -> None:
-    binary_version: str | None = None
+    binary_version: Optional[str] = None
     client_version: str = __version__
     try:
         configuration = configuration_module.create_configuration(arguments, Path("."))
@@ -479,44 +480,44 @@ def _check_configuration(configuration: configuration_module.Configuration) -> N
 )
 def pyre(
     context: click.Context,
-    local_configuration: str | None,
+    local_configuration: Optional[str],
     version: bool,
     debug: bool,
-    sequential: bool | None,
-    strict: bool | None,
+    sequential: Optional[bool],
+    strict: Optional[bool],
     additional_check: Iterable[str],
     show_error_traces: bool,
     output: str,
     enable_profiling: bool,
     enable_memory_profiling: bool,
     noninteractive: bool,
-    logging_sections: str | None,
-    log_identifier: str | None,
-    dot_pyre_directory: str | None,
-    logger: str | None,
+    logging_sections: Optional[str],
+    log_identifier: Optional[str],
+    dot_pyre_directory: Optional[str],
+    logger: Optional[str],
     target: Iterable[str],
-    use_buck_builder: bool | None,
-    buck_mode: str | None,
-    use_buck_source_database: bool | None,
+    use_buck_builder: Optional[bool],
+    buck_mode: Optional[str],
+    use_buck_source_database: Optional[bool],
     source_directory: Iterable[str],
-    filter_directory: str | None,
+    filter_directory: Optional[str],
     no_saved_state: bool,
     search_path: Iterable[str],
-    binary: str | None,
-    buck_builder_binary: str | None,
+    binary: Optional[str],
+    buck_builder_binary: Optional[str],
     exclude: Iterable[str],
-    typeshed: str | None,
-    save_initial_state_to: str | None,
-    load_initial_state_from: str | None,
-    changed_files_path: str | None,
-    saved_state_project: str | None,
-    features: str | None,
-    use_command_v2: bool | None,
-    isolation_prefix: str | None,
-    python_version: str | None,
-    shared_memory_heap_size: int | None,
-    shared_memory_dependency_table_power: int | None,
-    shared_memory_hash_table_power: int | None,
+    typeshed: Optional[str],
+    save_initial_state_to: Optional[str],
+    load_initial_state_from: Optional[str],
+    changed_files_path: Optional[str],
+    saved_state_project: Optional[str],
+    features: Optional[str],
+    use_command_v2: Optional[bool],
+    isolation_prefix: Optional[str],
+    python_version: Optional[str],
+    shared_memory_heap_size: Optional[int],
+    shared_memory_dependency_table_power: Optional[int],
+    shared_memory_hash_table_power: Optional[int],
 ) -> int:
     arguments = command_arguments.CommandArguments(
         local_configuration=local_configuration,
@@ -593,7 +594,11 @@ def pyre(
     type=filesystem.writable_directory,
     help="Directory to write analysis results to.",
 )
-@click.option("--dump-call-graph", is_flag=True, default=False, hidden=True)
+@click.option(
+    "--dump-call-graph",
+    type=str,
+    help="Dump the call graph in the given file.",
+)
 # pyre-fixme[56]: Pyre was not able to infer the type of argument `os.path.abspath`
 #  to decorator factory `click.option`.
 @click.option("--repository-root", type=os.path.abspath)
@@ -605,14 +610,13 @@ def pyre(
 )
 @click.option(
     "--find-missing-flows",
-    type=click.Choice([kind.value for kind in MissingFlowsKind]),
+    type=click.Choice([kind.value for kind in command_arguments.MissingFlowsKind]),
     help="Perform a taint analysis to find flows through obscure models.",
 )
 @click.option(
     "--dump-model-query-results",
-    is_flag=True,
-    default=False,
-    help="Provide model query debugging output.",
+    type=str,
+    help="Dump model query results in the given file.",
 )
 @click.option(
     "--use-cache",
@@ -642,49 +646,82 @@ def analyze(
     analysis: str,
     taint_models_path: Iterable[str],
     no_verify: bool,
-    save_results_to: str | None,
-    dump_call_graph: bool,
-    repository_root: str | None,
+    save_results_to: Optional[str],
+    dump_call_graph: Optional[str],
+    repository_root: Optional[str],
     rule: Iterable[int],
-    find_missing_flows: str | None,
-    dump_model_query_results: bool,
+    find_missing_flows: Optional[str],
+    dump_model_query_results: Optional[str],
     use_cache: bool,
     inline_decorators: bool,
-    maximum_trace_length: int | None,
-    maximum_tito_depth: int | None,
+    maximum_trace_length: Optional[int],
+    maximum_tito_depth: Optional[int],
 ) -> int:
     """
     Run Pysa, the inter-procedural static analysis tool.
     """
     command_argument: command_arguments.CommandArguments = context.obj["arguments"]
     configuration = _create_configuration_with_retry(command_argument, Path("."))
-    rules = list(rule)
-    return run_pyre_command(
-        commands.Analyze(
-            command_argument,
-            original_directory=os.getcwd(),
-            configuration=configuration,
-            analysis=analysis,
-            taint_models_path=list(taint_models_path),
-            no_verify=no_verify,
-            save_results_to=save_results_to,
-            dump_call_graph=dump_call_graph,
-            repository_root=repository_root,
-            rules=list(rules) if len(rules) > 0 else None,
-            find_missing_flows=(
-                MissingFlowsKind(find_missing_flows)
+
+    # TODO: Change the condition to `configuration.use_command_v2` when ready
+    if False:
+        _check_configuration(configuration)
+        _start_logging_to_directory(configuration.log_directory)
+        return v2.analyze.run(
+            configuration,
+            command_arguments.AnalyzeArguments(
+                debug=command_argument.debug,
+                dump_call_graph=dump_call_graph,
+                dump_model_query_results=dump_model_query_results,
+                enable_memory_profiling=command_argument.enable_memory_profiling,
+                enable_profiling=command_argument.enable_profiling,
+                find_missing_flows=command_arguments.MissingFlowsKind(
+                    find_missing_flows
+                )
                 if find_missing_flows is not None
-                else None
+                else None,
+                inline_decorators=inline_decorators,
+                log_identifier=command_argument.log_identifier,
+                maximum_tito_depth=maximum_tito_depth,
+                maximum_trace_length=maximum_trace_length,
+                no_verify=no_verify,
+                output=command_argument.output,
+                repository_root=repository_root,
+                rule=list(rule),
+                save_results_to=save_results_to,
+                sequential=command_argument.sequential,
+                taint_models_path=list(taint_models_path),
+                use_cache=use_cache,
             ),
-            dump_model_query_results=dump_model_query_results,
-            use_cache=use_cache,
-            inline_decorators=inline_decorators,
-            maximum_trace_length=maximum_trace_length,
-            maximum_tito_depth=maximum_tito_depth,
-        ),
-        configuration,
-        command_argument.noninteractive,
-    )
+        )
+    else:
+        rules = list(rule)
+        return run_pyre_command(
+            commands.Analyze(
+                command_argument,
+                original_directory=os.getcwd(),
+                configuration=configuration,
+                analysis=analysis,
+                taint_models_path=list(taint_models_path),
+                no_verify=no_verify,
+                save_results_to=save_results_to,
+                dump_call_graph=dump_call_graph,
+                repository_root=repository_root,
+                rules=list(rules) if len(rules) > 0 else None,
+                find_missing_flows=(
+                    command_arguments.MissingFlowsKind(find_missing_flows)
+                    if find_missing_flows is not None
+                    else None
+                ),
+                dump_model_query_results=dump_model_query_results,
+                use_cache=use_cache,
+                inline_decorators=inline_decorators,
+                maximum_trace_length=maximum_trace_length,
+                maximum_tito_depth=maximum_tito_depth,
+            ),
+            configuration,
+            command_argument.noninteractive,
+        )
 
 
 @pyre.command()
@@ -850,7 +887,7 @@ def incremental(
 @click.pass_context
 def infer(
     context: click.Context,
-    paths_to_modify: Iterable[str],
+    paths_to_modify: List[str],
     print_only: bool,
     in_place: bool,
     annotate_from_existing_stubs: bool,
@@ -876,7 +913,7 @@ def infer(
     working_directory = Path.cwd()
     modify_paths = (
         None
-        if not in_place
+        if len(paths_to_modify) == 0
         else {working_directory / Path(path) for path in paths_to_modify}
     )
     return v2.infer.run(
@@ -894,6 +931,7 @@ def infer(
             log_identifier=command_argument.log_identifier,
             logging_sections=command_argument.logging_sections,
             no_future_annotations=no_future_annotations,
+            in_place=in_place,
             paths_to_modify=modify_paths,
             print_only=print_only,
             read_stdin=read_stdin,
@@ -1107,7 +1145,9 @@ def query(context: click.Context, query: str) -> int:
     help="Number of server logs to include in the diagnositics. Default to 3.",
 )
 @click.pass_context
-def rage(context: click.Context, output_file: str | None, server_log_count: int) -> int:
+def rage(
+    context: click.Context, output_file: Optional[str], server_log_count: int
+) -> int:
     """
     Collects troubleshooting diagnostics for Pyre, and writes this information
     to the terminal or to a file.
